@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,18 +22,14 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::GenericInterface::Operation - GenericInterface Operation interface
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Operations are called by web service requests from remote
 systems.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 create an object.
 
@@ -66,7 +62,7 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
+    # Check needed objects.
     for my $Needed (qw(DebuggerObject Operation OperationType WebserviceID)) {
         if ( !$Param{$Needed} ) {
 
@@ -79,7 +75,7 @@ sub new {
         $Self->{$Needed} = $Param{$Needed};
     }
 
-    # check operation
+    # Check operation.
     if ( !IsStringWithData( $Param{OperationType} ) ) {
 
         return $Self->{DebuggerObject}->Error(
@@ -87,7 +83,7 @@ sub new {
         );
     }
 
-    # load backend module
+    # Load backend module.
     my $GenericModule = 'Kernel::GenericInterface::Operation::' . $Param{OperationType};
     if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($GenericModule) ) {
 
@@ -99,13 +95,13 @@ sub new {
         %{$Self},
     );
 
-    # pass back error message from backend if backend module could not be executed
+    # Pass back error message from backend if backend module could not be executed.
     return $Self->{BackendObject} if ref $Self->{BackendObject} ne $GenericModule;
 
     return $Self;
 }
 
-=item Run()
+=head2 Run()
 
 perform the selected Operation.
 
@@ -128,13 +124,46 @@ perform the selected Operation.
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # start map on backend
+    # Start map on backend,
     return $Self->{BackendObject}->Run(%Param);
 }
 
-1;
+=head2 HandleError()
 
-=back
+handle error data of the configured remote web service.
+
+    my $Result = $OperationObject->HandleError(
+        Data => {                               # data payload
+            ...
+        },
+    );
+
+    $Result = {
+        Success         => 1,                   # 0 or 1
+        ErrorMessage    => '',                  # in case of error
+        Data            => {                    # data payload after Invoker
+            ...
+        },
+    };
+
+=cut
+
+sub HandleError {
+    my ( $Self, %Param ) = @_;
+
+    # Check data - only accept undef or hash ref
+    if ( defined $Param{Data} && ref $Param{Data} ne 'HASH' ) {
+
+        return $Self->{DebuggerObject}->Error(
+            Summary => 'Got Data but it is not a hash ref in Operation handler (HandleResponse)!'
+        );
+    }
+
+    return $Self->{BackendObject}->HandleError(%Param);
+
+}
+
+1;
 
 =head1 TERMS AND CONDITIONS
 
