@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -349,7 +349,7 @@ sub Run {
 
     my $PermissionUserID = $UserID;
     if ( $UserType eq 'Customer' ) {
-        $UserID = $Kernel::OM->Get('Kernel::Config')->Get('CustomerPanelUserID')
+        $UserID = $Kernel::OM->Get('Kernel::Config')->Get('CustomerPanelUserID');
     }
 
     # check needed hashes
@@ -774,7 +774,7 @@ sub _CheckTicket {
     # if everything is OK then return Success
     return {
         Success => 1,
-        }
+    };
 }
 
 =head2 _CheckArticle()
@@ -1432,12 +1432,22 @@ sub _TicketCreate {
         ChannelName => $Article->{CommunicationChannel},
     );
 
+    my $PlainBody = $Article->{Body};
+
+    # Convert article body to plain text, if HTML content was supplied. This is necessary since auto response code
+    #   expects plain text content. Please see bug#13397 for more information.
+    if ( $Article->{ContentType} =~ /text\/html/i || $Article->{MimeType} =~ /text\/html/i ) {
+        $PlainBody = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToAscii(
+            String => $Article->{Body},
+        );
+    }
+
     # Create article.
     my $ArticleID = $ArticleBackendObject->ArticleCreate(
-        NoAgentNotify => $Article->{NoAgentNotify} || 0,
-        TicketID      => $TicketID,
-        SenderTypeID  => $Article->{SenderTypeID}  || '',
-        SenderType    => $Article->{SenderType}    || '',
+        NoAgentNotify        => $Article->{NoAgentNotify} || 0,
+        TicketID             => $TicketID,
+        SenderTypeID         => $Article->{SenderTypeID} || '',
+        SenderType           => $Article->{SenderType} || '',
         IsVisibleForCustomer => $Article->{IsVisibleForCustomer},
         From                 => $From,
         To                   => $To,
@@ -1454,7 +1464,7 @@ sub _TicketCreate {
             From    => $From,
             To      => $To,
             Subject => $Article->{Subject},
-            Body    => $Article->{Body},
+            Body    => $PlainBody,
         },
     );
 
@@ -1580,7 +1590,7 @@ sub _TicketCreate {
             Success      => 0,
             ErrorMessage => 'Could not get new ticket information, please contact the system'
                 . ' administrator',
-            }
+        };
     }
 
     # get web service configuration
