@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Operation::Ticket::TicketGet;
@@ -15,7 +15,7 @@ use MIME::Base64;
 
 use Kernel::System::VariableCheck qw(IsArrayRefWithData IsHashRefWithData IsStringWithData);
 
-use base qw(
+use parent qw(
     Kernel::GenericInterface::Operation::Common
     Kernel::GenericInterface::Operation::Ticket::Common
 );
@@ -26,15 +26,9 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::GenericInterface::Operation::Ticket::TicketGet - GenericInterface Ticket Get Operation backend
 
-=head1 SYNOPSIS
-
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Operation->new();
@@ -62,7 +56,7 @@ sub new {
     return $Self;
 }
 
-=item Run()
+=head2 Run()
 
 perform TicketGet Operation. This function is able to return
 one or more ticket entries in one call.
@@ -85,8 +79,9 @@ one or more ticket entries in one call.
             ArticleSenderType    => [ $ArticleSenderType1, $ArticleSenderType2 ],  # Optional, only requested article sender types
             ArticleOrder         => 'DESC',                                        # Optional, DESC,ASC - default is ASC
             ArticleLimit         => 5,                                             # Optional
-            Attachments          => 1,                                             # Optional, 1 as default. If it's set with the value 1,
+            Attachments          => 1,                                             # Optional, 0 as default. If it's set with the value 1,
                                                                                    # attachments for articles will be included on ticket data
+            GetAttachmentContents = 1                                              # Optional, 1 as default. 0|1,
             HTMLBodyAsAttachment => 1                                              # Optional, If enabled the HTML body version of each article
                                                                                    #    is added to the attachments list
         },
@@ -124,7 +119,6 @@ one or more ticket entries in one call.
                     ResponsibleID      => 123,
                     Age                => 3456,
                     Created            => '2010-10-27 20:15:00'
-                    CreateTimeUnix     => '1231414141',
                     CreateBy           => 123,
                     Changed            => '2010-10-27 20:15:15',
                     ChangeBy           => 123,
@@ -177,7 +171,6 @@ one or more ticket entries in one call.
                     FirstResponseInMin              (minutes till first response)
                     FirstResponseDiffInMin          (minutes till or over first response)
 
-                    SolutionTime                    (timestamp of solution time, also close time)
                     SolutionInMin                   (minutes till solution time)
                     SolutionDiffInMin               (minutes till or over solution time)
 
@@ -197,8 +190,7 @@ one or more ticket entries in one call.
                             References
                             SenderType
                             SenderTypeID
-                            ArticleType
-                            ArticleTypeID
+                            IsVisibleForCustomer
                             ContentType
                             Charset
                             MimeType
@@ -218,8 +210,8 @@ one or more ticket entries in one call.
                                     ContentAlternative => "",
                                     ContentID          => "",
                                     ContentType        => "application/pdf",
+                                    FileID             => 34,
                                     Filename           => "StdAttachment-Test1.pdf",
-                                    Filesize           => "4.6 KBytes",
                                     FilesizeRaw        => 4722,
                                 },
                                 {
@@ -290,7 +282,7 @@ sub Run {
         );
     }
 
-    # Get the list of dynamic fields for object article.
+    # Get the list of article dynamic fields
     my $ArticleDynamicFieldList = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldList(
         ObjectType => 'Article',
         ResultType => 'HASH',
@@ -322,7 +314,9 @@ sub Run {
     my $ArticleOrder  = $Param{Data}->{ArticleOrder}  || 'ASC';
     my $ArticleLimit  = $Param{Data}->{ArticleLimit}  || 0;
     my $Attachments   = $Param{Data}->{Attachments}   || 0;
-    my $ReturnData    = {
+    my $GetAttachmentContents = $Param{Data}->{GetAttachmentContents} // 1;
+
+    my $ReturnData = {
         Success => 1,
     };
     my @Item;
@@ -335,14 +329,16 @@ sub Run {
         $ArticleSenderType = [ $Param{Data}->{ArticleSenderType} ];
     }
 
-    # By default does not include HYML body as attachment (3) unless is explicitly requested (2).
-    my $StripPlainBodyAsAttachment = $Param{Data}->{HTMLBodyAsAttachment} ? 2 : 3;
+    # By default, do not include HTML body as attachment, unless it is explicitly requested.
+    my %ExcludeAttachments = (
+        ExcludePlainText => 1,
+        ExcludeHTMLBody  => $Param{Data}->{HTMLBodyAsAttachment} ? 0 : 1,
+    );
 
     # start ticket loop
     TICKET:
     for my $TicketID (@TicketIDs) {
 
-        # get ticket object
         my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
         # get the Ticket entry
@@ -367,7 +363,7 @@ sub Run {
         my %TicketEntry;
         my @DynamicFields;
 
-        # remove all dynamic fields form main ticket hash and set them into an array.
+        # remove all dynamic fields from main ticket hash and set them into an array.
         ATTRIBUTE:
         for my $Attribute ( sort keys %TicketEntryRaw ) {
 
@@ -382,6 +378,10 @@ sub Run {
             $TicketEntry{$Attribute} = $TicketEntryRaw{$Attribute};
         }
 
+        $TicketEntry{TimeUnit} = $TicketObject->TicketAccountedTimeGet(
+            TicketID => $TicketID,
+        );
+
         # add dynamic fields array into 'DynamicField' hash key if any
         if (@DynamicFields) {
             $TicketEntry{DynamicField} = \@DynamicFields;
@@ -397,35 +397,60 @@ sub Run {
             next TICKET;
         }
 
-        my $ArticleTypes;
+        my %ArticleListFilters;
         if ( $UserType eq 'Customer' ) {
-            $ArticleTypes = [ $TicketObject->ArticleTypeList( Type => 'Customer' ) ];
+            %ArticleListFilters = (
+                IsVisibleForCustomer => 1,
+            );
         }
 
-        my @ArticleBoxRaw = $TicketObject->ArticleGet(
-            TicketID          => $TicketID,
-            ArticleSenderType => $ArticleSenderType,
-            ArticleType       => $ArticleTypes,
-            DynamicFields     => $DynamicFields,
-            Extended          => $Extended,
-            Order             => $ArticleOrder,
-            Limit             => $ArticleLimit,
-            UserID            => $UserID,
-        );
+        my $ArticleObject = $Kernel::OM->Get('Kernel::System::Ticket::Article');
+
+        my @Articles;
+        if ($ArticleSenderType) {
+            for my $SenderType ( @{ $ArticleSenderType || [] } ) {
+                my @ArticlesFiltered = $ArticleObject->ArticleList(
+                    TicketID   => $TicketID,
+                    SenderType => $SenderType,
+                    %ArticleListFilters,
+                );
+                push @Articles, @ArticlesFiltered;
+            }
+        }
+        else {
+            @Articles = $ArticleObject->ArticleList(
+                TicketID => $TicketID,
+                %ArticleListFilters,
+            );
+        }
+
+        # Set number of articles by ArticleLimit and ArticleOrder parameters.
+        if ( IsArrayRefWithData( \@Articles ) && $ArticleLimit ) {
+            if ( $ArticleOrder eq 'DESC' ) {
+                @Articles = reverse @Articles;
+            }
+            @Articles = @Articles[ 0 .. ( $ArticleLimit - 1 ) ];
+        }
 
         # start article loop
         ARTICLE:
-        for my $Article (@ArticleBoxRaw) {
+        for my $Article (@Articles) {
+
+            my $ArticleBackendObject = $ArticleObject->BackendForArticle( %{$Article} );
+
+            my %ArticleData = $ArticleBackendObject->ArticleGet(
+                TicketID      => $TicketID,
+                ArticleID     => $Article->{ArticleID},
+                DynamicFields => $DynamicFields,
+            );
+            $Article = \%ArticleData;
 
             next ARTICLE if !$Attachments;
 
             # get attachment index (without attachments)
-            my %AtmIndex = $TicketObject->ArticleAttachmentIndex(
-                ContentPath                => $Article->{ContentPath},
-                ArticleID                  => $Article->{ArticleID},
-                StripPlainBodyAsAttachment => $StripPlainBodyAsAttachment,
-                Article                    => $Article,
-                UserID                     => $UserID,
+            my %AtmIndex = $ArticleBackendObject->ArticleAttachmentIndex(
+                ArticleID => $Article->{ArticleID},
+                %ExcludeAttachments,
             );
 
             next ARTICLE if !IsHashRefWithData( \%AtmIndex );
@@ -434,16 +459,24 @@ sub Run {
             ATTACHMENT:
             for my $FileID ( sort keys %AtmIndex ) {
                 next ATTACHMENT if !$FileID;
-                my %Attachment = $TicketObject->ArticleAttachment(
+                my %Attachment = $ArticleBackendObject->ArticleAttachment(
                     ArticleID => $Article->{ArticleID},
                     FileID    => $FileID,                 # as returned by ArticleAttachmentIndex
-                    UserID    => $UserID,
                 );
 
                 next ATTACHMENT if !IsHashRefWithData( \%Attachment );
 
-                # convert content to base64
-                $Attachment{Content} = encode_base64( $Attachment{Content} );
+                $Attachment{FileID} = $FileID;
+                if ($GetAttachmentContents)
+                {
+                    # convert content to base64
+                    $Attachment{Content} = encode_base64( $Attachment{Content} );
+                }
+                else {
+                    # unset content
+                    $Attachment{Content}            = '';
+                    $Attachment{ContentAlternative} = '';
+                }
                 push @Attachments, {%Attachment};
             }
 
@@ -453,21 +486,22 @@ sub Run {
         }    # finish article loop
 
         # set Ticket entry data
-        if (@ArticleBoxRaw) {
+        if (@Articles) {
 
             my @ArticleBox;
 
-            for my $ArticleRaw (@ArticleBoxRaw) {
+            for my $ArticleRaw (@Articles) {
                 my %Article;
                 my @ArticleDynamicFields;
 
-                # remove all dynamic fields form main article hash and set them into an array.
+                # remove all dynamic fields from main article hash and set them into an array.
                 ATTRIBUTE:
                 for my $Attribute ( sort keys %{$ArticleRaw} ) {
 
                     if ( $Attribute =~ m{\A DynamicField_(.*) \z}msx ) {
 
-                        # Skip dynamic fields that are not for article object
+                        # skip dynamic fields that are not article related
+                        # this is needed because ArticleGet() also returns ticket dynamic fields
                         next ATTRIBUTE if ( !$ArticleDynamicFieldLookup{$1} );
 
                         push @ArticleDynamicFields, {
@@ -480,6 +514,10 @@ sub Run {
                     $Article{$Attribute} = $ArticleRaw->{$Attribute};
                 }
 
+                $Article{TimeUnit} = $ArticleObject->ArticleAccountedTimeGet(
+                    ArticleID => $ArticleRaw->{ArticleID}
+                );
+
                 # add dynamic fields array into 'DynamicField' hash key if any
                 if (@ArticleDynamicFields) {
                     $Article{DynamicField} = \@ArticleDynamicFields;
@@ -514,14 +552,12 @@ sub Run {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
