@@ -185,7 +185,10 @@ sub OverviewScreen {
     }
 
     # build output
-    my $Output = $LayoutObject->Header( Title => 'Overview' );
+    my $Output = $LayoutObject->Header(
+        Title => Translatable('Overview'),
+        Area  => 'Statistics',
+    );
     $Output .= $LayoutObject->NavigationBar();
 
     $Output .= $LayoutObject->Output(
@@ -208,7 +211,10 @@ sub ImportScreen {
 
     my %Errors = %{ $Param{Errors} // {} };
 
-    my $Output = $LayoutObject->Header( Title => 'Import' );
+    my $Output = $LayoutObject->Header(
+        Title => Translatable('Import'),
+        Area  => 'Statistics',
+    );
     $Output .= $LayoutObject->NavigationBar();
     $Output .= $LayoutObject->Output(
         TemplateFile => 'AgentStatisticsImport',
@@ -362,7 +368,10 @@ sub EditScreen {
         );
     }
 
-    my $Output = $LayoutObject->Header( Title => 'Edit' );
+    my $Output = $LayoutObject->Header(
+        Title => Translatable('Edit'),
+        Area  => 'Statistics',
+    );
     $Output .= $LayoutObject->NavigationBar();
 
     $Output .= $LayoutObject->Output(
@@ -743,7 +752,10 @@ sub ViewScreen {
         UserID => $Self->{UserID},
     );
 
-    my $Output = $LayoutObject->Header( Title => 'View' );
+    my $Output = $LayoutObject->Header(
+        Title => Translatable('View'),
+        Area  => 'Statistics',
+    );
     $Output .= $LayoutObject->NavigationBar();
 
     $Output .= $LayoutObject->Output(
@@ -816,6 +828,7 @@ sub AddScreen {
     # build output
     my $Output = $LayoutObject->Header(
         Title => Translatable('Add New Statistic'),
+        Area  => 'Statistics',
     );
     $Output .= $LayoutObject->NavigationBar();
     $Output .= $LayoutObject->Output(
