@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::AuthSession::DB;
@@ -11,18 +11,18 @@ package Kernel::System::AuthSession::DB;
 use strict;
 use warnings;
 
-use Storable qw();
 use MIME::Base64 qw();
 
 use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::DateTime',
     'Kernel::System::DB',
     'Kernel::System::Encode',
     'Kernel::System::Log',
     'Kernel::System::Main',
-    'Kernel::System::Time',
+    'Kernel::System::Storable',
 );
 
 sub new {
@@ -94,7 +94,7 @@ sub CheckSessionID {
     }
 
     # check session idle time
-    my $TimeNow            = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $TimeNow            = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
     my $MaxSessionIdleTime = $ConfigObject->Get('SessionMaxIdleTime');
 
     if ( ( $TimeNow - $MaxSessionIdleTime ) >= $Data{UserLastRequest} ) {
@@ -178,6 +178,9 @@ sub GetSessionIDData {
     # get encode object
     my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
 
+    # get storable object
+    my $StorableObject = $Kernel::OM->Get('Kernel::System::Storable');
+
     my %Session;
     my %SessionID;
     ROW:
@@ -185,7 +188,9 @@ sub GetSessionIDData {
 
         # deserialize data if needed
         if ( $Row[3] ) {
-            my $Value = eval { Storable::thaw( MIME::Base64::decode_base64( $Row[2] ) ) };
+            my $Value = eval {
+                $StorableObject->Deserialize( Data => MIME::Base64::decode_base64( $Row[2] ) );
+            };
 
             # workaround for the oracle problem with empty
             # strings and NULL values in VARCHAR columns
@@ -221,7 +226,7 @@ sub GetSessionIDData {
 sub CreateSessionID {
     my ( $Self, %Param ) = @_;
 
-    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $TimeNow = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
 
     # get remote address and the http user agent
     my $RemoteAddr      = $ENV{REMOTE_ADDR}     || 'none';
@@ -382,7 +387,7 @@ sub GetActiveSessions {
     my $MaxSessionIdleTime = $Kernel::OM->Get('Kernel::Config')->Get('SessionMaxIdleTime');
 
     # get system time
-    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $TimeNow = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
 
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
@@ -454,7 +459,7 @@ sub GetExpiredSessionIDs {
     my $MaxSessionIdleTime = $ConfigObject->Get('SessionMaxIdleTime');
 
     # get current time
-    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $TimeNow = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
 
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
@@ -622,6 +627,8 @@ sub _SQLCreate {
     return if !$Param{SQLs};
     return if ref $Param{SQLs} ne 'ARRAY';
 
+    my $StorableObject = $Kernel::OM->Get('Kernel::System::Storable');
+
     if ( $Self->{DBType} eq 'mysql' || $Self->{DBType} eq 'postgresql' ) {
 
         # define row
@@ -645,7 +652,9 @@ sub _SQLCreate {
             {
 
                 # dump the data
-                $Value      = MIME::Base64::encode_base64( Storable::nfreeze($Value) );
+                $Value = MIME::Base64::encode_base64(
+                    $StorableObject->Serialize( Data => $Value )
+                );
                 $Serialized = 1;
             }
 
@@ -709,7 +718,9 @@ sub _SQLCreate {
                 }
 
                 # dump the data
-                $Value      = MIME::Base64::encode_base64( Storable::nfreeze($Value) );
+                $Value = MIME::Base64::encode_base64(
+                    $StorableObject->Serialize( Data => $Value )
+                );
                 $Serialized = 1;
             }
 
@@ -775,7 +786,9 @@ sub _SQLCreate {
             {
 
                 # dump the data
-                $Value      = MIME::Base64::encode_base64( Storable::nfreeze($Value) );
+                $Value = MIME::Base64::encode_base64(
+                    $StorableObject->Serialize( Data => $Value )
+                );
                 $Serialized = 1;
             }
 
