@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Environment;
@@ -25,22 +25,16 @@ our @ObjectDependencies = (
 
 Kernel::System::Environment - collect environment info
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Functions to collect environment info
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 create environment object. Do not use it directly, instead use:
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $EnvironmentObject = $Kernel::OM->Get('Kernel::System::Environment');
 
 =cut
@@ -55,7 +49,7 @@ sub new {
     return $Self;
 }
 
-=item OSInfoGet()
+=head2 OSInfoGet()
 
 collect operating system information
 
@@ -89,13 +83,6 @@ sub OSInfoGet {
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
-    my %OSMap = (
-        linux   => 'Linux',
-        freebsd => 'FreeBSD',
-        openbsd => 'OpenBSD',
-        darwin  => 'MacOSX',
-    );
-
     # If used OS is a linux system
     my $OSName;
     my $Distribution;
@@ -127,6 +114,9 @@ sub OSInfoGet {
                 $OSName = $Content->[0];
             }
         }
+        else {
+            $OSName = "Unknown version";
+        }
     }
     elsif ( $^O eq 'darwin' ) {
 
@@ -136,17 +126,23 @@ sub OSInfoGet {
         $OSName = 'MacOSX ' . $MacVersion;
     }
     elsif ( $^O eq 'freebsd' || $^O eq 'openbsd' ) {
-
-        my $BSDVersion = `uname -r` || '';
-        chomp $BSDVersion;
-
-        $OSName = "$OSMap{$^O} $BSDVersion";
+        $OSName = `uname -r`;
     }
+    else {
+        $OSName = "Unknown";
+    }
+
+    my %OSMap = (
+        linux   => 'Linux',
+        freebsd => 'FreeBSD',
+        openbsd => 'OpenBSD',
+        darwin  => 'MacOSX',
+    );
 
     # collect OS data
     my %EnvOS = (
         Hostname     => hostname_long(),
-        OSName       => $OSName || 'Unknown version',
+        OSName       => $OSName,
         Distribution => $Distribution,
         User         => $ENV{USER} || $ENV{USERNAME},
         Path         => $ENV{PATH},
@@ -161,7 +157,7 @@ sub OSInfoGet {
     return %EnvOS;
 }
 
-=item ModuleVersionGet()
+=head2 ModuleVersionGet()
 
 Return the version of an installed perl module:
 
@@ -205,7 +201,7 @@ sub ModuleVersionGet {
     return MM->parse_version($Path);
 }
 
-=item PerlInfoGet()
+=head2 PerlInfoGet()
 
 collect perl information:
 
@@ -253,12 +249,9 @@ sub PerlInfoGet {
             CGI
             Class::Inspector
             Crypt::PasswdMD5
-            Crypt::Random::Source
             CSS::Minifier
-            Date::Pcalc
             Email::Valid
             Encode::Locale
-            Exporter::Tiny
             IO::Interactive
             JavaScript::Minifier
             JSON
@@ -268,12 +261,8 @@ sub PerlInfoGet {
             LWP
             Mail::Address
             Mail::Internet
-            Math::Random::ISAAC
-            Math::Random::Secure
             MIME::Tools
-            Module::Find
             Module::Refresh
-            Moo
             Mozilla::CA
             Net::IMAP::Simple
             Net::HTTP
@@ -283,10 +272,8 @@ sub PerlInfoGet {
             Sys::Hostname::Long
             Text::CSV
             Text::Diff
-            Types::TypeTiny
             YAML
             URI
-            namespace::clean
             )
             )
         {
@@ -302,7 +289,7 @@ sub PerlInfoGet {
     return %EnvPerl;
 }
 
-=item DBInfoGet()
+=head2 DBInfoGet()
 
 collect database information
 
@@ -339,7 +326,7 @@ sub DBInfoGet {
     return %EnvDB;
 }
 
-=item OTRSInfoGet()
+=head2 OTRSInfoGet()
 
 collect OTRS information
 
@@ -379,14 +366,12 @@ sub OTRSInfoGet {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
