@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,9 +11,11 @@ package Kernel::System::MailAccount::IMAPS;
 use strict;
 use warnings;
 
+# There are currently errors on Perl 5.20 on Travis, disable this check for now.
+## nofilter(TidyAll::Plugin::OTRS::Perl::SyntaxCheck)
 use IO::Socket::SSL;
 
-use base qw(Kernel::System::MailAccount::IMAP);
+use parent qw(Kernel::System::MailAccount::IMAP);
 
 our @ObjectDependencies = (
     'Kernel::System::Log',
@@ -25,11 +27,10 @@ sub Connect {
     # check needed stuff
     for (qw(Login Password Host Timeout Debug)) {
         if ( !defined $Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
+            return (
+                Successful => 0,
+                Message    => "Need $_!",
             );
-            return;
         }
     }
 
